@@ -10,10 +10,13 @@
 
 #include "defs.hpp"
 #include "col_reader.hpp"
+#include "line_writer.hpp"
 #include "array_col_reader.hpp"
 #include "_line_to_array.hpp"
 #include "line_to_tuple.hpp"
 #include "exp_averager.hpp"
+#include "enumerator.hpp"
+#include "correlator.hpp"
 
 using namespace std;
 
@@ -30,9 +33,17 @@ static PyMethodDef dagpype_c_methods[] =
     { "parser_max_field_len", (PyCFunction)parser_max_field_len, METH_VARARGS, NULL},
     { "col_reader", (PyCFunction)col_reader, METH_VARARGS, NULL},
     { "col_reader_parse_string", (PyCFunction)col_reader_parse_string, METH_VARARGS, NULL},
+    { "line_writer", (PyCFunction)line_writer, METH_VARARGS, NULL},
+    { "line_writer_write", (PyCFunction)line_writer_write, METH_VARARGS, NULL},
+    { "line_writer_close", (PyCFunction)line_writer_close, METH_VARARGS, NULL},
     { "array_col_reader", (PyCFunction)array_col_reader, METH_VARARGS, NULL},
     { "exp_averager", (PyCFunction)exp_averager, METH_VARARGS, NULL},
     { "exp_averager_ave", (PyCFunction)exp_averager_ave, METH_VARARGS, NULL},
+    { "enumerator", (PyCFunction)enumerator, METH_VARARGS, NULL},
+    { "enumerator_next", (PyCFunction)enumerator_next, METH_VARARGS, NULL},
+    { "correlator", (PyCFunction)correlator, METH_VARARGS, NULL},
+    { "correlator_push", (PyCFunction)correlator_push, METH_VARARGS, NULL},
+    { "correlator_corr", (PyCFunction)correlator_corr, METH_VARARGS, NULL},
     { NULL, NULL }
 };
 
